!-----------------------BEGIN NOTICE -- DO NOT EDIT-----------------------
! NASA Goddard Space Flight Center Land Information System (LIS) v7.2
!
! Copyright (c) 2015 United States Government as represented by the
! Administrator of the National Aeronautics and Space Administration.
! All Rights Reserved.
!-------------------------END NOTICE -- DO NOT EDIT-----------------------
!BOP
!
! !ROUTINE: create_gdasT1534filename
!  \label{create_gdasT1534filename}
!
! !REVISION HISTORY:
!  20 June 2014: Sujay Kumar; initial implementation
! !INTERFACE:
subroutine create_gdasT1534filename(name, gdasdir, yr, mo, da, hr)
! !USES:

  use LIS_timeMgrMod,     only : LIS_tick

  implicit none
! !ARGUMENTS: 
  character(len=*)             :: name
  character(len=*), intent(in) :: gdasdir
  integer                      :: yr
  integer                      :: mo
  integer                      :: da
  integer                      :: hr
!  
! !DESCRIPTION:
!
!EOP
  integer :: i, c
  integer :: uyr, umo, uda, uhr, umn, uss
  real    :: ts1
  integer :: ghh, gff
  integer :: remainder
  integer :: doy
  real    :: gmt
  real*8  :: dumbtime
  character(len=2) :: initcode, fcstcode
  character*1 :: fbase(80), fdir(15), ftime(10), fsubs(22)
  character(LEN=100) :: temp
!=== End Variable Definition ===============

!=== formats for filename segments
!BOC
92 format (80a1)
93 format (a80)
94 format (i4, i2, i2, a2)
95 format (10a1)
96 format (a40)
97 format (a16, a2, a3)
98 format (a1, i4, i2, a1)
99 format (8a1)
!-----------------------------------------------------------------
!  Make variables for the time used to create the file
!  We don't want these variables being passed out
!-----------------------------------------------------------------
  dumbtime = 0.
  doy = 1
  gmt = 0.
  uyr = yr
  umo = mo
  uda = da
  uhr = hr
  umn = 0
  uss = 0
  ts1 = -1.0*60*60 !roll back date.

  ghh = hr 
  if ( ghh .EQ. 0 ) then
     call LIS_tick(dumbtime, doy, gmt, uyr, umo, uda, uhr, umn, uss, ts1)
     ghh = 24
  endif

  gff = modulo(ghh,6) 
  if ( gff .EQ. 0 ) gff =  6
  ghh = ghh - gff
 
  write(initcode,'(i2.2)') ghh
  write(fcstcode,'(i2.2)') gff

  write(UNIT=temp, fmt='(a40)') gdasdir  
  read(UNIT=temp, fmt='(80a1)') (fbase(i), i=1,80)
  c = 0
  do i = 1, 80
     if ( fbase(i) .NE. ' ' ) c = c + 1
  end do

  write(UNIT=temp, fmt='(a6, i4, i2, i2, a1)') '/gdas.',uyr,umo,uda,'/'
  read(UNIT=temp, fmt='(15a1)') fdir
  do i = 1, 15
     if ( fdir(i) == ' ' ) fdir(i) = '0'
  end do

  write(UNIT=temp, fmt='(a7,a2,a11,a2)') &
        'gdas1.t',initcode,'z.sfluxgrbf',fcstcode

  read(UNIT=temp, fmt='(22a1)') fsubs

  write(UNIT=temp, fmt='(80a1)') &
        (fbase(i),i=1,c), (fdir(i),i=1,15), (fsubs(i),i=1,22)

  read(UNIT=temp, fmt='(a80)') name

end subroutine create_gdasT1534filename


