!-----------------------BEGIN NOTICE -- DO NOT EDIT-----------------------
! NASA Goddard Space Flight Center Land Information System (LIS) v7.2
!
! Copyright (c) 2015 United States Government as represented by the
! Administrator of the National Aeronautics and Space Administration.
! All Rights Reserved.
!-------------------------END NOTICE -- DO NOT EDIT-----------------------
!BOP
! !ROUTINE: noahmp36_settws
!  \label{noahmp36_settws}
!
! !REVISION HISTORY:
! 14 Mar 2017: Sujay Kumar; Initial Specification
!
! !INTERFACE:
subroutine noahmp36_settws(n, LSM_State)
! !USES:
  use ESMF
  use LIS_coreMod
  use LIS_logMod
  use noahmp36_lsmMod
  use module_sf_noahlsm_36  !MN

  implicit none
! !ARGUMENTS: 
  integer, intent(in)    :: n
  type(ESMF_State)       :: LSM_State
!
! !DESCRIPTION:
!  
!  This routine assigns the soil moisture prognostic variables to noah's
!  model space. 
! 
!EOP
  real, parameter        :: MIN_THRESHOLD = 0.02 
  real                   :: MAX_threshold
  real                   :: sm_threshold
  type(ESMF_Field)       :: sm1Field
  type(ESMF_Field)       :: sm2Field
  type(ESMF_Field)       :: sm3Field
  type(ESMF_Field)       :: sm4Field
  real, pointer          :: soilm1(:)
  real, pointer          :: soilm2(:)
  real, pointer          :: soilm3(:)
  real, pointer          :: soilm4(:)
  integer                :: t, j,i, gid, m, t_unpert
  integer                :: status
  real                   :: delta(4)
  real                   :: delta1,delta2,delta3,delta4
  real                   :: tmpval
  logical                :: bounds_violation
  integer                :: nIter
  logical                :: update_flag(LIS_rc%ngrid(n))
  logical                :: ens_flag(LIS_rc%nensem(n))
! mn
  integer                :: SOILTYP           ! soil type index [-]
  real                   :: SMCMAX , SMCWLT
  real                   :: tmp(LIS_rc%nensem(n)), tmp0(LIS_rc%nensem(n))
  real                   :: tmp1(LIS_rc%nensem(n)),tmp2(LIS_rc%nensem(n)),tmp3(LIS_rc%nensem(n)),tmp4(LIS_rc%nensem(n)) 
  logical                :: update_flag_tile(LIS_rc%npatch(n,LIS_rc%lsm_index))
  logical                :: flag_ens(LIS_rc%ngrid(n))
  logical                :: flag_tmp(LIS_rc%nensem(n))
  logical                :: update_flag_ens(LIS_rc%ngrid(n))
  logical                :: update_flag_new(LIS_rc%ngrid(n))
  integer                :: RESULT, icount
  real                   :: MaxEnsSM1 ,MaxEnsSM2 ,MaxEnsSM3 ,MaxEnsSM4
  real                   :: MinEnsSM1 ,MinEnsSM2 ,MinEnsSM3 ,MinEnsSM4 
  real                   :: MaxEns_sh2o1, MaxEns_sh2o2, MaxEns_sh2o3, MaxEns_sh2o4
  real                   :: smc_rnd, smc_tmp 
  real                   :: sh2o_tmp, sh2o_rnd 
  INTEGER, DIMENSION (1) :: seed 

  call ESMF_StateGet(LSM_State,"Soil Moisture Layer 1",sm1Field,rc=status)
  call LIS_verify(status,&
       "ESMF_StateSet: Soil Moisture Layer 1 failed in noahmp36_settws")
  call ESMF_StateGet(LSM_State,"Soil Moisture Layer 2",sm2Field,rc=status)
  call LIS_verify(status,&
       "ESMF_StateSet: Soil Moisture Layer 2 failed in noahmp36_settws")
  call ESMF_StateGet(LSM_State,"Soil Moisture Layer 3",sm3Field,rc=status)
  call LIS_verify(status,&
       "ESMF_StateSet: Soil Moisture Layer 3 failed in noahmp36_settws")
  call ESMF_StateGet(LSM_State,"Soil Moisture Layer 4",sm4Field,rc=status)
  call LIS_verify(status,&
       "ESMF_StateSet: Soil Moisture Layer 4 failed in noahmp36_settws")

  call ESMF_FieldGet(sm1Field,localDE=0,farrayPtr=soilm1,rc=status)
  call LIS_verify(status,&
       "ESMF_FieldGet: Soil Moisture Layer 1 failed in noahmp36_settws")
  call ESMF_FieldGet(sm2Field,localDE=0,farrayPtr=soilm2,rc=status)
  call LIS_verify(status,&
       "ESMF_FieldGet: Soil Moisture Layer 2 failed in noahmp36_settws")
  call ESMF_FieldGet(sm3Field,localDE=0,farrayPtr=soilm3,rc=status)
  call LIS_verify(status,&
       "ESMF_FieldGet: Soil Moisture Layer 3 failed in noahmp36_settws")
  call ESMF_FieldGet(sm4Field,localDE=0,farrayPtr=soilm4,rc=status)
  call LIS_verify(status,&
       "ESMF_FieldGet: Soil Moisture Layer 4 failed in noahmp36_settws")

  update_flag = .true. 
  update_flag_tile= .true. 

  do t=1,LIS_rc%npatch(n,LIS_rc%lsm_index)
  
 ! MN: NOTE: SMCMAX and SMCWLT are not stored in the data structure but we 
 !       can get module variables MAXSMC and WLTSMC from the module_sf_noahlsm_36       
     SOILTYP = NOAHMP36_struc(n)%noahmp36(t)%soiltype        
     MAX_THRESHOLD = MAXSMC (SOILTYP)
     sm_threshold = MAXSMC (SOILTYP) - 0.02
     !sm_threshold = NOAHMP36_struc(n)%noahmp36(t)%smcmax - 0.02
     !MAX_THRESHOLD = NOAHMP36_struc(n)%noahmp36(t)%smcmax
     
     gid = LIS_domain(n)%gindex(&
          LIS_surface(n,LIS_rc%lsm_index)%tile(t)%col,&
          LIS_surface(n,LIS_rc%lsm_index)%tile(t)%row) 
     
     !MN: delta = X(+) - X(-)
     !NOTE: "noahmp36_updatesoilm.F90" updates the soilm_(t)     
     delta1 = soilm1(t)-NOAHMP36_struc(n)%noahmp36(t)%smc(1)
     delta2 = soilm2(t)-NOAHMP36_struc(n)%noahmp36(t)%smc(2)
     delta3 = soilm3(t)-NOAHMP36_struc(n)%noahmp36(t)%smc(3)
     delta4 = soilm4(t)-NOAHMP36_struc(n)%noahmp36(t)%smc(4)

     ! MN: check    MIN_THRESHOLD < volumetric liquid soil moisture < threshold 
     if(NOAHMP36_struc(n)%noahmp36(t)%sh2o(1)+delta1.gt.MIN_THRESHOLD .and.&
          NOAHMP36_struc(n)%noahmp36(t)%sh2o(1)+delta1.lt.&
          sm_threshold) then 
        update_flag(gid) = update_flag(gid).and.(.true.)
        ! MN save the flag for each tile (col*row*ens)   (64*44)*20
        update_flag_tile(t) = update_flag_tile(t).and.(.true.)
     else
        update_flag(gid) = update_flag(gid).and.(.false.)
        update_flag_tile(t) = update_flag_tile(t).and.(.false.)
     endif
     if(NOAHMP36_struc(n)%noahmp36(t)%sh2o(2)+delta2.gt.MIN_THRESHOLD .and.&
          NOAHMP36_struc(n)%noahmp36(t)%sh2o(2)+delta2.lt.sm_threshold) then 
        update_flag(gid) = update_flag(gid).and.(.true.)
        update_flag_tile(t) = update_flag_tile(t).and.(.true.)
     else
        update_flag(gid) = update_flag(gid).and.(.false.)
        update_flag_tile(t) = update_flag_tile(t).and.(.false.)
     endif
     if(NOAHMP36_struc(n)%noahmp36(t)%sh2o(3)+delta3.gt.MIN_THRESHOLD .and.&
          NOAHMP36_struc(n)%noahmp36(t)%sh2o(3)+delta3.lt.sm_threshold) then 
        update_flag(gid) = update_flag(gid).and.(.true.)
        update_flag_tile(t) = update_flag_tile(t).and.(.true.)
     else
        update_flag(gid) = update_flag(gid).and.(.false.)
        update_flag_tile(t) = update_flag_tile(t).and.(.false.)
     endif
     if(NOAHMP36_struc(n)%noahmp36(t)%sh2o(4)+delta4.gt.MIN_THRESHOLD .and.&
          NOAHMP36_struc(n)%noahmp36(t)%sh2o(4)+delta4.lt.sm_threshold) then 
        update_flag(gid) = update_flag(gid).and.(.true.)
        update_flag_tile(t) = update_flag_tile(t).and.(.true.)
     else
        update_flag(gid) = update_flag(gid).and.(.false.)
        update_flag_tile(t) = update_flag_tile(t).and.(.false.)
     endif
  enddo

!-----------------------------------------------------------------------------------------
! MN create new falg: if update falg for 50% of the ensemble members is true 
! then update the state variabels 
!-----------------------------------------------------------------------------------------
  update_flag_ens = .True.
  do i=1,LIS_rc%npatch(n,LIS_rc%lsm_index)/LIS_rc%nensem(n)
     gid =i 
     flag_tmp=update_flag_tile((i-1)*LIS_rc%nensem(n)+1:(i)*LIS_rc%nensem(n))
     RESULT = COUNT(flag_tmp) 
     if (RESULT.lt.LIS_rc%nensem(n)*0.5) then   !>10/20*100 = 50%
        update_flag_ens(gid)= .False.
     endif
     update_flag_new(gid)= update_flag(gid).or.update_flag_ens(gid)  ! new flag
  enddo
  
  
  ! MN print 
  if(i.eq.66) then !i=66  ! --> domain's center  1376
  if(LIS_rc%hr.eq.12) then
     write(2001,'(I4, 2x, 3(I2,x), 2x, 23(L1,2x))'),&
          i, LIS_rc%mo, LIS_rc%da, LIS_rc%hr,update_flag_tile&
          ((i-1)*LIS_rc%nensem(n)+1:(i)*LIS_rc%nensem(n)),&
          update_flag_ens(i), update_flag_new(i), update_flag(i) 
  endif !mn
  endif
  
  ! update step
  ! loop over grid points 
  do i=1,LIS_rc%npatch(n,LIS_rc%lsm_index)/LIS_rc%nensem(n)
     
     gid =i 
     
     !if(update_flag(gid)) then
     if(update_flag_new(gid)) then 
!-----------------------------------------------------------------------------------------
       ! 1- update the states
       ! 1-1- if update flag for tile is TRUE --> apply the DA update    
       ! 1-2- if update flag for tile is FALSE --> resample the states  
       ! 2- adjust the states
!-----------------------------------------------------------------------------------------
        ! store update value for  cases that update_flag_tile & update_flag_new are TRUE
        ! update_flag_tile = TRUE --> means met the both min and max threshold 
      
        tmp1 = LIS_rc%udef
        tmp2 = LIS_rc%udef
        tmp3 = LIS_rc%udef
        tmp4 = LIS_rc%udef
	!icount = 1
        do m=1,LIS_rc%nensem(n)
           t = (i-1)*LIS_rc%nensem(n)+m
 
	  if(update_flag_tile(t)) then
          
           tmp1(m) = soilm1(t) 
           tmp2(m) = soilm2(t) 
           tmp3(m) = soilm3(t) 
           tmp4(m) = soilm4(t) 
           !icount = icount + 1 
          endif
        enddo
        
        !MaxEnsSM1 = MAXVAL(tmp1)
        !MaxEnsSM2 = MAXVAL(tmp2)
        !MaxEnsSM3 = MAXVAL(tmp3)
        !MaxEnsSM4 = MAXVAL(tmp4)

        !MinEnsSM1 = MINVAL(tmp1(1:icount - 1))
        !MinEnsSM2 = MINVAL(tmp2(1:icount - 1))
        !MinEnsSM3 = MINVAL(tmp3(1:icount - 1))
        !MinEnsSM4 = MINVAL(tmp4(1:icount - 1))


        MaxEnsSM1 = -10000
        MaxEnsSM2 = -10000
        MaxEnsSM3 = -10000
        MaxEnsSM4 = -10000

        MinEnsSM1 = 10000
        MinEnsSM2 = 10000
        MinEnsSM3 = 10000
        MinEnsSM4 = 10000

        do m=1,LIS_rc%nensem(n)
           if(tmp1(m).ne.LIS_rc%udef) then 
              MaxEnsSM1 = max(MaxEnsSM1, tmp1(m))
              MaxEnsSM2 = max(MaxEnsSM2, tmp2(m))
              MaxEnsSM3 = max(MaxEnsSM3, tmp3(m))
              MaxEnsSM4 = max(MaxEnsSM4, tmp4(m))

              MinEnsSM1 = min(MinEnsSM1, tmp1(m))
              MinEnsSM2 = min(MinEnsSM2, tmp2(m))
              MinEnsSM3 = min(MinEnsSM3, tmp3(m))
              MinEnsSM4 = min(MinEnsSM4, tmp4(m))
              
           endif
        enddo


       !if(i.eq.1376) then
       ! print*,'max_sm',MaxEnsSM1,MaxEnsSM2, MaxEnsSM3, MaxEnsSM4
       ! print*,'min_sm',MinEnsSM1,MinEnsSM2, MinEnsSM3, MinEnsSM4
       !endif

        
        !do m=1,LIS_rc%nensem(n)
        !  t = (i-1)*LIS_rc%nensem(n)+m
           
        !   tmp1(t) = NOAHMP36_struc(n)%noahmp36(t)%sh2o(1)
        !   tmp2(t) = NOAHMP36_struc(n)%noahmp36(t)%sh2o(2)
        !   tmp3(t) = NOAHMP36_struc(n)%noahmp36(t)%sh2o(3)
        !   tmp4(t) = NOAHMP36_struc(n)%noahmp36(t)%sh2o(4)
        !enddo
        
        !MaxEns_sh2o1 = MAXVAL(tmp1)
        !MaxEns_sh2o2 = MAXVAL(tmp2)
        !MaxEns_sh2o3 = MAXVAL(tmp3)
        !MaxEns_sh2o4 = MAXVAL(tmp4)
        
        
        ! loop over tile       
        do m=1,LIS_rc%nensem(n)
           t = (i-1)*LIS_rc%nensem(n)+m
           
           ! MN check update status for each tile  
           if(update_flag_tile(t)) then
              
              delta1 = soilm1(t)-NOAHMP36_struc(n)%noahmp36(t)%smc(1)
              delta2 = soilm2(t)-NOAHMP36_struc(n)%noahmp36(t)%smc(2)
              delta3 = soilm3(t)-NOAHMP36_struc(n)%noahmp36(t)%smc(3)
              delta4 = soilm4(t)-NOAHMP36_struc(n)%noahmp36(t)%smc(4)
              
              !! MN print
              !!tmp=0.0
              !!tmp0=0.0
              !if(i.eq.66) then
              !   tmp(m) = NOAHMP36_struc(n)%noahmp36(t)%smc(1)
              !   tmp0(m) = soilm1(t)
              !endif
              !!mn
              


              NOAHMP36_struc(n)%noahmp36(t)%sh2o(1) = NOAHMP36_struc(n)%noahmp36(t)%sh2o(1)+&
                   delta1
              NOAHMP36_struc(n)%noahmp36(t)%smc(1) = soilm1(t)
              if(soilm1(t).lt.0) then 
                 print*, 'setsoilm1 ',t,soilm1(t)
                 stop
              endif
              if(NOAHMP36_struc(n)%noahmp36(t)%sh2o(2)+delta2.gt.MIN_THRESHOLD .and.&
                   NOAHMP36_struc(n)%noahmp36(t)%sh2o(2)+delta2.lt.sm_threshold) then 
                 NOAHMP36_struc(n)%noahmp36(t)%sh2o(2) = NOAHMP36_struc(n)%noahmp36(t)%sh2o(2)+&
                      soilm2(t)-NOAHMP36_struc(n)%noahmp36(t)%smc(2)
                 NOAHMP36_struc(n)%noahmp36(t)%smc(2) = soilm2(t)
                 if(soilm2(t).lt.0) then 
                    print*, 'setsoilm2 ',t,soilm2(t)
                    stop
                 endif
              endif
! MN: Test shutdown the update for 4th layer   
              if(NOAHMP36_struc(n)%noahmp36(t)%sh2o(3)+delta3.gt.MIN_THRESHOLD .and.&
                   NOAHMP36_struc(n)%noahmp36(t)%sh2o(3)+delta3.lt.sm_threshold) then 
                 NOAHMP36_struc(n)%noahmp36(t)%sh2o(3) = NOAHMP36_struc(n)%noahmp36(t)%sh2o(3)+&
                      soilm3(t)-NOAHMP36_struc(n)%noahmp36(t)%smc(3)
                 NOAHMP36_struc(n)%noahmp36(t)%smc(3) = soilm3(t)
                 if(soilm3(t).lt.0) then 
                    print*, 'setsoilm3 ',t,soilm3(t)
                    stop
                 endif
              endif

              if(NOAHMP36_struc(n)%noahmp36(t)%sh2o(4)+delta4.gt.MIN_THRESHOLD .and.&
                   NOAHMP36_struc(n)%noahmp36(t)%sh2o(4)+delta4.lt.sm_threshold) then 
                 NOAHMP36_struc(n)%noahmp36(t)%sh2o(4) = NOAHMP36_struc(n)%noahmp36(t)%sh2o(4)+&
                      soilm4(t)-NOAHMP36_struc(n)%noahmp36(t)%smc(4)
                 NOAHMP36_struc(n)%noahmp36(t)%smc(4) = soilm4(t)

                 if(soilm4(t).lt.0) then 
                    print*, 'setsoilm4 ',t,soilm4(t)
                    stop
                 endif
              endif
              
              
!-----------------------------------------------------------------------------------------              
              ! randomly resample the smc from [MIN_THRESHOLD,  Max value from DA @ that tiem step]
!-----------------------------------------------------------------------------------------
           else 
              
              !! Generate random number 
              !seed = t+LIS_rc%da+LIS_rc%hr
              !CALL RANDOM_SEED (PUT=seed)
              !CALL RANDOM_NUMBER(sh2o_rnd) 
              !seed = 2*t+LIS_rc%da+LIS_rc%hr      
              !CALL RANDOM_SEED (PUT=seed)
              !CALL RANDOM_NUMBER(smc_rnd)
              
 !-----------------------------------------------------------------------------------------             
              ! scale the random number to soil moisture values 
              ! i.e. scale to [MIN_THRESHOLD and max value from DA 4 each layer]
	      ! DOES NOT WORK --> VERY SMALL VALUE FOR THE ENS. MET THIS CONDITION 

              ! LET'S TRY USING MEAN VALUE 

!-----------------------------------------------------------------------------------------
              !smc_tmp = smc_rnd *(MaxEnsSM1 - MIN_THRESHOLD) + MIN_THRESHOLD
              !sh2o_tmp = sh2o_rnd *(MaxEns_sh2o1 - MIN_THRESHOLD) + MIN_THRESHOLD

              ! LET'S TRY USING MEAN VALUE               
              ! use mean value
              ! Assume sh2o = smc (i.e. ice content=0) 
              smc_tmp = (MaxEnsSM1 - MinEnsSM1)/2 + MinEnsSM1
              NOAHMP36_struc(n)%noahmp36(t)%sh2o(1) = smc_tmp 
              NOAHMP36_struc(n)%noahmp36(t)%smc(1) = smc_tmp
              
              
              smc_tmp = (MaxEnsSM2 - MinEnsSM2)/2 + MinEnsSM2            
              NOAHMP36_struc(n)%noahmp36(t)%sh2o(2) = smc_tmp
              NOAHMP36_struc(n)%noahmp36(t)%smc(2) = smc_tmp
              
! MN: Test shutdown the update for 3rd and 4th layer   
              smc_tmp = (MaxEnsSM3 - MinEnsSM3)/2 + MinEnsSM3
              NOAHMP36_struc(n)%noahmp36(t)%sh2o(3) = smc_tmp
              NOAHMP36_struc(n)%noahmp36(t)%smc(3) = smc_tmp
              

              smc_tmp = (MaxEnsSM4 - MinEnsSM4)/2 + MinEnsSM4
              NOAHMP36_struc(n)%noahmp36(t)%sh2o(4) = smc_tmp
              NOAHMP36_struc(n)%noahmp36(t)%smc(4) = smc_tmp
              
 
           endif ! flag for each tile

        enddo ! loop over tile
 




              !! MN write output twic first for analysis step then for update step
              !if(i.eq.66 .and. LIS_rc%hr.eq.12) then

               !  print*,'layers_max_sm',MaxEnsSM1,MaxEnsSM2, MaxEnsSM3, MaxEnsSM4
               !  !print*, 'layers_max_sho2',MaxEns_sh2o1,MaxEns_sh2o2,MaxEns_sh2o3,MaxEns_sh2o4  

               !  write(201,*) 'i, mm, dd, hr,mn, flag, sm+,sm-',&
                !      i, LIS_rc%mo, LIS_rc%da, LIS_rc%hr, LIS_rc%mn,&
                !      update_flag(gid),&
                !      (sum(tmp0))/LIS_rc%nensem(n),&
                !      (sum(tmp))/LIS_rc%nensem(n)
                ! 
                ! write(2011,'(I4, 2x, 3(I2,x), 2x, 20(f11.8,2x))'),&
                !      i, LIS_rc%mo, LIS_rc%da, LIS_rc%hr,tmp0
                 
              !endif
              !tmp=0.0
              !tmp0=0.0






       
     else ! if update_flag_new(gid) is FALSE   
        if(LIS_rc%pert_bias_corr.eq.1) then           
           !--------------------------------------------------------------------------
           ! if no update is made, then we need to readjust the ensemble if pert bias
           ! correction is turned on because the forcing perturbations may cause 
           ! biases to persist. 
           !--------------------------------------------------------------------------
           bounds_violation = .true. 
           nIter = 0
           ens_flag = .true. 
           
           do while(bounds_violation) 
              niter = niter + 1
              t_unpert = i*LIS_rc%nensem(n)
              do j=1,4
                 delta(j) = 0.0
                 do m=1,LIS_rc%nensem(n)-1
                    t = (i-1)*LIS_rc%nensem(n)+m
                    
                    if(m.ne.LIS_rc%nensem(n)) then 
                       delta(j) = delta(j) + &
                            (NOAHMP36_struc(n)%noahmp36(t)%sh2o(j) - &
                            NOAHMP36_struc(n)%noahmp36(t_unpert)%sh2o(j))
                    endif
                    
                 enddo
              enddo
              
              do j=1,4
                 delta(j) =delta(j)/(LIS_rc%nensem(n)-1)
                 do m=1,LIS_rc%nensem(n)-1
                    t = (i-1)*LIS_rc%nensem(n)+m
                    SOILTYP = NOAHMP36_struc(n)%noahmp36(t)%soiltype  
                    MAX_THRESHOLD = MAXSMC (SOILTYP)
                    sm_threshold = MAXSMC (SOILTYP) - 0.02
                    
                    tmpval = NOAHMP36_struc(n)%noahmp36(t)%sh2o(j) - &
                         delta(j)
                    if(tmpval.le.MIN_THRESHOLD) then 
                       NOAHMP36_struc(n)%noahmp36(t)%sh2o(j) = &
                            max(NOAHMP36_struc(n)%noahmp36(t_unpert)%sh2o(j),&
                            MIN_THRESHOLD)
                       NOAHMP36_struc(n)%noahmp36(t)%smc(j) = &
                            max(NOAHMP36_struc(n)%noahmp36(t_unpert)%smc(j),&
                            MIN_THRESHOLD)
                       ens_flag(m) = .false. 
                    elseif(tmpval.ge.sm_threshold) then
                       NOAHMP36_struc(n)%noahmp36(t)%sh2o(j) = &
                            min(NOAHMP36_struc(n)%noahmp36(t_unpert)%sh2o(j),&
                            sm_threshold)
                       NOAHMP36_struc(n)%noahmp36(t)%smc(j) = &
                            min(NOAHMP36_struc(n)%noahmp36(t_unpert)%smc(j),&
                            sm_threshold)
                       ens_flag(m) = .false. 
                    endif
                 enddo
              enddo
              
              !--------------------------------------------------------------------------
              ! Recalculate the deltas and adjust the ensemble
              !--------------------------------------------------------------------------
              do j=1,4
                 delta(j) = 0.0
                 do m=1,LIS_rc%nensem(n)-1
                    t = (i-1)*LIS_rc%nensem(n)+m
                    if(m.ne.LIS_rc%nensem(n)) then 
                       delta(j) = delta(j) + &
                            (NOAHMP36_struc(n)%noahmp36(t)%sh2o(j) - &
                            NOAHMP36_struc(n)%noahmp36(t_unpert)%sh2o(j))
                    endif
                 enddo
              enddo
              
              do j=1,4
                 delta(j) =delta(j)/(LIS_rc%nensem(n)-1)
                 do m=1,LIS_rc%nensem(n)-1
                    t = (i-1)*LIS_rc%nensem(n)+m
                    
                    if(ens_flag(m)) then 
                       tmpval = NOAHMP36_struc(n)%noahmp36(t)%sh2o(j) - &
                            delta(j)
                       SOILTYP = NOAHMP36_struc(n)%noahmp36(t)%soiltype  
                       MAX_THRESHOLD = MAXSMC (SOILTYP) 
                       
                       if(.not.(tmpval.le.0.0 .or.&
                            tmpval.gt.(MAX_THRESHOLD))) then 
                          
                          NOAHMP36_struc(n)%noahmp36(t)%smc(j) = &
                               NOAHMP36_struc(n)%noahmp36(t)%smc(j) - delta(j)
                          NOAHMP36_struc(n)%noahmp36(t)%sh2o(j) = &
                               NOAHMP36_struc(n)%noahmp36(t)%sh2o(j) - delta(j)
                          bounds_violation = .false.
                       endif
                    endif
                    
                    tmpval = NOAHMP36_struc(n)%noahmp36(t)%sh2o(j)
                    SOILTYP = NOAHMP36_struc(n)%noahmp36(t)%soiltype  
                    MAX_THRESHOLD = MAXSMC (SOILTYP) 
                    
                    if(tmpval.le.0.0 .or.&
                         tmpval.gt.(MAX_THRESHOLD)) then 
                       bounds_violation = .true. 
                    else
                       bounds_violation = .false.
                    endif
                 enddo
              enddo
              
              if(nIter.gt.10.and.bounds_violation) then 
                 !--------------------------------------------------------------------------
                 ! All else fails, set to the bounds
                 !--------------------------------------------------------------------------
                 
                 write(LIS_logunit,*) '[ERR] Ensemble structure violates physical bounds '
                 write(LIS_logunit,*) '[ERR] Please adjust the perturbation settings ..'

                 do j=1,4
                    do m=1,LIS_rc%nensem(n)
                       t = (i-1)*LIS_rc%nensem(n)+m
                       
                       SOILTYP = NOAHMP36_struc(n)%noahmp36(t)%soiltype  
                       MAX_THRESHOLD = MAXSMC (SOILTYP)            
                       
                       if(NOAHMP36_struc(n)%noahmp36(t)%sh2o(j).gt.MAX_THRESHOLD.or.&
                            NOAHMP36_struc(n)%noahmp36(t)%smc(j).gt.MAX_THRESHOLD) then                        
                          NOAHMP36_struc(n)%noahmp36(t)%sh2o(j) = MAX_THRESHOLD
                          NOAHMP36_struc(n)%noahmp36(t)%smc(j) = MAX_THRESHOLD
                       endif
                       
                       if(NOAHMP36_struc(n)%noahmp36(t)%sh2o(j).lt.MIN_THRESHOLD.or.&
                            NOAHMP36_struc(n)%noahmp36(t)%smc(j).lt.MIN_THRESHOLD) then                        
                          NOAHMP36_struc(n)%noahmp36(t)%sh2o(j) = MIN_THRESHOLD
                          NOAHMP36_struc(n)%noahmp36(t)%smc(j) = MIN_THRESHOLD
                       endif
!                    print*, i, m
!                    print*, 'smc',t, NOAHMP36_struc(n)%noahmp36(t)%smc(:)
!                    print*, 'sh2o ',t,NOAHMP36_struc(n)%noahmp36(t)%sh2o(:)
!                    print*, 'max ',t,MAX_THRESHOLD !NOAHMP36_struc(n)%noahmp36(t)%smcmax
                    enddo
                  call LIS_endrun()
                 enddo



!                 do m=1,LIS_rc%nensem(n)
!                    t = (i-1)*LIS_rc%nensem(n)+m
!                    SOILTYP = NOAHMP36_struc(n)%noahmp36(t)%soiltype  
!                    MAX_THRESHOLD = MAXSMC (SOILTYP)            
!                    print*, i, m
!                    print*, 'smc',t, NOAHMP36_struc(n)%noahmp36(t)%smc(:)
!                    print*, 'sh2o ',t,NOAHMP36_struc(n)%noahmp36(t)%sh2o(:)
!                    print*, 'max ',t,MAX_THRESHOLD !NOAHMP36_struc(n)%noahmp36(t)%smcmax
!                 enddo
!                 print*, 'ens ',ens_flag
!                 call LIS_endrun()
              endif
              
           end do
        endif
        
        
        
        !! MN write the variables for the case the update flag is false
        !if(i.eq.66) then
        !   do m=1,LIS_rc%nensem(n)
        !      t = (i-1)*LIS_rc%nensem(n)+m
        !      tmp(m) = NOAHMP36_struc(n)%noahmp36(t)%smc(1)      
        !      print*,'mm, dd, final_sm1_update ', LIS_rc%mo, LIS_rc%da ,&
        !           NOAHMP36_struc(n)%noahmp36(t)%smc(1) , tmp(m)
        !   enddo
        !   print*,' '
        !   write(202,*) 'mm, dd, hh, sm_adj ', LIS_rc%mo, LIS_rc%da ,&
        !        LIS_rc%hr, (sum(tmp))/LIS_rc%nensem(n)    
        !   !sum(NOAHMP36_struc(n)%noahmp36((i-1)*LIS_rc%nensem(n)+1:(i-1)*&
        !   !LIS_rc%nensem(n)+LIS_rc%nensem(n))%smc(1))/LIS_rc%nensem(n)            
        !   !mn
        !endif
        
        !!! MN
        !!if(j.eq.1 .and. i.eq.66) then
        !!   tmp(m) = NOAHMP36_struc(n)%noahmp36(t)%smc(j)  
        !!endif
        !!! mn
        
        
        
     endif
  enddo
  
  
  !MN: write the output for all cases. first writes the analysis step
  !   then writes the updated/adjusted states
  tmp1=0.0  
  tmp2=0.0
  tmp3=0.0
  tmp4=0.0
  if(i.eq.66) then !i=66
  if(LIS_rc%hr.eq.12) then
     do m=1,LIS_rc%nensem(n)
        t = (i-1)*LIS_rc%nensem(n)+m
        tmp1(m) = NOAHMP36_struc(n)%noahmp36(t)%smc(1)   
        tmp2(m) = NOAHMP36_struc(n)%noahmp36(t)%smc(2)      
        tmp3(m) = NOAHMP36_struc(n)%noahmp36(t)%smc(3)      
        tmp4(m) = NOAHMP36_struc(n)%noahmp36(t)%smc(4)         
     enddo
    !  'mm, dd, hr, sm1+/adj , sm2+/adj, sm3+/adj, sm4+/adj'
    write(203,'(4(I2,x), 2x, 4(f11.8,2x))'),LIS_rc%mo, LIS_rc%da ,LIS_rc%hr, LIS_rc%mn, &
	        (sum(tmp1))/LIS_rc%nensem(n), &  
		(sum(tmp2))/LIS_rc%nensem(n), &  
		(sum(tmp3))/LIS_rc%nensem(n), &  
		(sum(tmp4))/LIS_rc%nensem(n)  
 
     
     write(2031,'(3(I2,x), 2x, 20(f11.8,2x))'),&
          LIS_rc%mo, LIS_rc%da, LIS_rc%hr, tmp 
     
  endif !mn
endif

end subroutine noahmp36_settws

