!-----------------------BEGIN NOTICE -- DO NOT EDIT-----------------------
! NASA Goddard Space Flight Center Land Information System (LIS) v7.2
!
! Copyright (c) 2015 United States Government as represented by the
! Administrator of the National Aeronautics and Space Administration.
! All Rights Reserved.
!-------------------------END NOTICE -- DO NOT EDIT-----------------------
program readgrib_test
!=========================================================================
!
! PROGRAM:: stage4_gis.f90
!
! DESCRIPTION::
!   This program opens, reads and a sample grib file using the read_grib
!   library.
!  
! REVISION HISTORY::
!   06 May 2006:  K. Arsenault -- Modified code for ease of use and
!                                 further enhanced for ArcGIS format
!
!   07 May 2007:  Sujay Kumar   - incorporated into the LIS test suite. !
!=========================================================================

   implicit none

!-- Input parameters:

    character(len=40) :: stage4_file

!-- Other parameters:
    integer, parameter :: ndat = 987601
    integer :: ifn, iret, jret, n
    integer :: isec
    integer :: lugi         ! Unit of the unblocked grib index file 
    integer :: num_in_pts   ! Requires an input of . . . how many points there are???
    integer :: num_mskip    ! Number of messages to skip ( =0 to search from beginning)
    integer :: num_out_pts  ! Number of data points unpacked (should be same as num_in_pts)
    integer :: msg_unpkd    ! Message number unpacked

    real , dimension(ndat) :: datarray

    integer, dimension(100) :: ksec1
    integer, dimension(10)  :: ksec2
    integer, dimension(40)  :: iginfo
    real*4,  dimension(40)  :: ginfo
    logical :: success
    integer :: i, ufn, ncol, nrow
    real*4  :: alat1, alon1, alonv, dx


    success = .true. 
!-- Initialize certain variables and parameters of Grib file:
  
    lugi = 0; num_mskip = 0
!-- Establish name of Stage IV Grib file to be opened and read:
    stage4_file = 'sample_gribfile.Grb'

!    ifn = 10
!-- Open Stage IV Grib File:
!    ndat = 987601
!    call gribdata (datarray, ndat)
    call copen(1,ifn, trim(stage4_file)//char(0),1,iret,0)
    print*,'1) file open ',iret    

    print *, " Calling gribget next . . . "
    call gribget(ifn, iret)
    print*,'2) gribget ',iret    

!    call gribprint(isec)

    if ( iret .ne.0) then   ! Return File Error Code Number - IF FAILED TO OPEN!
       write(*,*) "STOPPING ROUTINE -- FILE NOT OPENED DUE TO CODE # :: ", iret
       success = .false. 
     else

!-- Gather and Define Information Needed to Read Grib File:
!-- Extract GRIB header information from the STAGE II/IV File
!    call gribget(ufn,iret);  print*,'(1) gribget return ',iret
        call gribheader(jret) ;  print*,'(1) gribheader return ',jret

!-- Obtain GRIB Grid information: 
        call get_gridinfo (iginfo, ginfo)
        ncol = iginfo(1); print *, "-- NX :: ", ncol
        nrow = iginfo(2); print *, "-- NY :: ", nrow
        alat1 = ginfo(3); print *, "-- Init Lat :: ", alat1
        alon1 = ginfo(4); print *, "-- Init Lon :: ", alon1
        alonv = ginfo(6); print *, "-- Center Lon :: ", alonv
        dx    = ginfo(7); print *, "-- DX :: ", dx

     endif

!-- Close the Stage IV Grib File:
     print*, '-------------------------------------------'
     if(success) then 
        print*, 'All tests worked successfully for read_grib'
     else
        print*, 'Tests failed for w3lib'
     endif
     print*, '-------------------------------------------'
   end program readgrib_test

