!-----------------------BEGIN NOTICE -- DO NOT EDIT-----------------------
! NASA Goddard Space Flight Center Land Information System (LIS) v7.2
!
! Copyright (c) 2015 United States Government as represented by the
! Administrator of the National Aeronautics and Space Administration.
! All Rights Reserved.
!-------------------------END NOTICE -- DO NOT EDIT-----------------------
!=========================================================================
!
! PROGRAM:: w3lib_test.F90
!
! DESCRIPTION::
!   This program opens, reads and a sample grib file using the NCEP 
!   grib libraries. 
!  
! REVISION HISTORY::
!   18 Feb 2000:  B. Cosgrove -- Initial code written 
!   01 Oct 2005:  J. Triggs   -- Further developed code for ArcGIS use
!   06 May 2006:  K. Arsenault -- Modified code for ease of use and
!                                 further enhanced for ArcGIS format
!   07 May 2007:  Sujay Kumar   - incorporated into the LIS test suite. 
!
!=========================================================================
program w3lib_test

  implicit none
  
!-- Input parameters:


  character(len=40) :: stage2_file 

!-- Other parameters:
  integer :: ifn, iret, jret, n
  integer :: lugi         ! Unit of the unblocked grib index file 
  integer :: num_in_pts   ! Requires an input of . . . how many points there are???
  integer :: num_mskip    ! Number of messages to skip ( =0 to search from beginning)
  integer :: jpds(200)     ! PDS Parameters for which to search (=-1 for wildcard)
  integer :: jgds(200)     ! GDS Parameters for which to serach (=-1 for wildcard)
  integer :: num_out_pts  ! Number of data points unpacked (should be same as num_in_pts)
  integer :: msg_unpkd    ! Message number unpacked
  integer :: kpds(200)     ! Unpacked PDS parameters
  integer :: kgds(200)    ! Upacked GDS parameters
  
!    logical*1, allocatable :: lb(:)   ! Unpacked bitmap, if present (array length = num_in_pts)
!    real, allocatable :: s2_ppt(:)    ! Stage II Precipitation Data Array (output from GETGB)
  logical*1 :: lb(987601)   ! Unpacked bitmap, if present (array length = num_in_pts)
  real :: s2_ppt(987601)    ! Stage II Precipitation Data Array (output from GETGB)


  integer :: iopt
  logical :: success 

!-- Initialize certain variables and parameters of Grib file:
  success = .true.
  ifn = 10; lugi = 0; num_mskip = 0
  do n = 1, 25
     jpds(n) = -1
     jgds(n) = 0 
    end do
!-- Establish name of Stage II Grib file to be opened and read:
    stage2_file = './sample_gribfile.Grb'
    

    ifn = ifn+1
    print *, "FILE NUMBER: ", ifn 

!-- Open Stage II Grib File:
    call baopenr (ifn, stage2_file, iret)

    if ( iret .ne. 0) then   ! Return File Error Code Number - IF FAILED TO OPEN!
       print*, "ERROR -- FILE NOT OPENED DUE TO CODE # :: ", iret
       success = .false.
    else

!-- Gather and Define Information Needed to Read Grib File:
!rec 1:0:date 2001123123 APCP kpds5=61 kpds6=1 kpds7=0 levels=(0,0) grid=240 sfc 0-1hr acc: bitmap: 393675 undef
!  APCP=Total precipitation [kg/m^2]
!  timerange 4 P1 0 P2 1 TimeU 1  nx 1121 ny 881 GDS grid 5 num_in_ave 0 missing 0
!  center 7 subcenter 0 process 152 Table 2
!  polar stereo: Lat1 23.117000 Long1 240.977000 Orient 255.000000
!     north pole (1121 x 881) Dx 4763 Dy 4763 scan 64
!  min/max data 0 19.2  num bits 8  BDS_Ref 0  DecScale 1 BinScale 0
   
    jpds(1) = 7       ! ID of Center
    jpds(2) = 152     ! Generating Process ID Number
    jpds(3) = 240     ! Grid Definition
    jpds(5) = 61      ! Indicator of Parameter
    jpds(6) = 1       ! Type of Level
    jpds(7) = 000     ! Height/Pressure Level

    jgds(1) = 5
    jgds(2) = 1121
    jgds(3) = 881
    jgds(4) = 23.117000
    jgds(5) = 240.977000
    jgds(7) = 255.000000
    jgds(8) = 4763
    jgds(9) = 4763
    jgds(11) = 64

    if (iret == 0 ) then
!  -- Read the contents of the Stage II Grib File:
!      call getgb ( lugb, lugi, nstage4, j, jpds, jgds,  &
!                   kf, k, kpds, kgdss4,lb, s4in, iret)

       num_in_pts = 987601
!       allocate ( lb(num_in_pts), s2_ppt(num_in_pts) )
       s2_ppt = 0
       call getgb ( ifn, lugi, num_in_pts, num_mskip, jpds, jgds, &
                    num_out_pts, msg_unpkd, kpds, kgds, lb, s2_ppt, iret)

!       print *, ifn, lugi, num_in_pts, num_mskip, num_out_pts, msg_unpkd, jgds

       do n = 1, num_in_pts
          if (s2_ppt(n) > 0 ) print *, s2_ppt(n)
       end do

       if ( iret > 0) then   ! Return File Error Code Number - IF FAILED TO READ!
          write(*,*) "STOPPING ROUTINE -- FILE NOT READ DUE TO CODE # :: ", iret
!         stop
          success = .false.
       end if

    end if

!-- Close the Stage II Grib File:
    call baclose (ifn, jret)
    if ( jret > 0) then   ! Return File Error Code Number - IF FAILED TO CLOSE!
       write(*,*) "STOPPING ROUTINE -- FILE NOT CLOSED DUE TO CODE # :: ", jret
       success = .false.
    end if
 endif
 print*, '-------------------------------------------'
 if(success) then 
    print*, 'All tests worked successfully for w3lib'
 else
    print*, 'Tests failed for w3lib'
 endif
 print*, '-------------------------------------------'
end program w3lib_test
